@@ -162,8 +162,6 @@ class ByRow(AutoFit):
             The total number of rows in the grid
         *items_to_move :
             One or more global Ids.
-         : TYPE
-            DESCRIPTION.
 
         Returns
         -------
@@ -207,9 +205,6 @@ class ByColumn(AutoFit):
             The total number of rows in the grid
         *items_to_move :
             One or more global Ids.
-         : TYPE
-            DESCRIPTION.
-
         """
         super().__init__(
             column_index,
@@ -960,10 +955,14 @@ class ImageContainerPost(ContainerPost):
     Define a new ImageContainer to create.
     """
 
+    def _setencoded(self, img_file):
+        image_b64 = base64.b64encode(img_file.read()).decode("ascii")
+        self.data["newBase64LocationsImage"] = "data:image/png;base64," + str(image_b64)
+
     def __init__(
         self,
         name: str,
-        image_file_path: str,
+        image_file: Union[str, io.BufferedReader],
         locations: Optional[Sequence] = [],
         tags: Optional[str] = None,
         description: Optional[str] = None,
@@ -978,9 +977,10 @@ class ImageContainerPost(ContainerPost):
         name : str
             Name of the image container.
         image_file_path : str
-            A full file path to the image to use.
+            A full file path to the image to use, or BufferedReader file object.
         locations : Optional[Sequence], optional
-            An optional list of (x,y) coordinate tuples of marked locations.
+            An optional list of (x,y) coordinate tuples of marked locations within
+            the image container.
         tags : Optional[str], optional
             Comma separated tags
         description : Optional[str], optional
@@ -990,7 +990,7 @@ class ImageContainerPost(ContainerPost):
         can_store_samples : bool, optional
             The default is True.
         location : TargetLocation, optional
-            The default is TopLevelTargetLocation.
+            Where this new container will be located. The default is TopLevelTargetLocation.
         """
         super().__init__(
             name,
@@ -1001,11 +1001,12 @@ class ImageContainerPost(ContainerPost):
             can_store_samples,
             location,
         )
-        with open(image_file_path, "rb") as img_file:
-            image_b64 = base64.b64encode(img_file.read()).decode("ascii")
-            self.data["newBase64LocationsImage"] = "data:image/png;base64," + str(
-                image_b64
-            )
+
+        if isinstance(image_file, str):
+            with open(image_file, "rb") as img_file:
+                self._setencoded(img_file)
+        elif isinstance(image_file, io.BufferedReader):
+            self._setencoded(image_file)
         locs = [{"coordX": p[0], "coordY": p[1]} for p in locations]
         self.data["locations"] = locs
         self.data["cType"] = "IMAGE"
@@ -1087,7 +1088,6 @@ class InventoryClient(ClientBase):
             )
         toPost = [s.data for s in sample_posts]
         bulk_post = {"operationType": "CREATE", "records": toPost}
-        print(bulk_post)
         return self._do_bulk(bulk_post)
 
     def create_sample(
@@ -1132,9 +1132,8 @@ class InventoryClient(ClientBase):
             "/samples", request_type="POST", params=toPost.data
         )
         if attachments is not None:
-            self.serr(f"adding {len(attachments)} attachments")
             for file in attachments:
-                self.uploadAttachment(sample["globalId"], file)
+                self.upload_attachment(sample["globalId"], file)
             ## get latest version
             sample = self.get_sample_by_id(sample["id"])
         return sample
@@ -1206,7 +1205,9 @@ class InventoryClient(ClientBase):
         if sample_filter is not None:
             pagination.data.update(sample_filter.data)
         return self.retrieve_api_results(
-            f"/{endpoint}", request_type="GET", params=pagination.data,
+            f"/{endpoint}",
+            request_type="GET",
+            params=pagination.data,
         )
 
     def stream_samples(
@@ -1260,6 +1261,31 @@ class InventoryClient(ClientBase):
             f"/{endpoint}/{s_id.as_id()}", request_type="PUT", params={"name": new_name}
         )
 
+    def set_image(self, item_id: Union[str, dict], file) -> dict:
+        """
+        Sets image for a sample, subsample or container
+
+        Parameters
+        ----------
+        item_id : Union[str, dict]
+            The id or dict of the item to set the image for.
+        file : File object
+            An open file object.
+
+        Returns
+        -------
+        dict
+            The upddated item with links of rel=image and rel=thumnail set.
+
+        """
+        s_id = Id(item_id)
+        endpoint = s_id.get_api_endpoint()
+        image_b64 = base64.b64encode(file.read()).decode("ascii")
+        data = {"newBase64Image": "data:image/png;base64," + str(image_b64)}
+        return self.retrieve_api_results(
+            f"/{endpoint}/{s_id.as_id()}", request_type="PUT", params=data
+        )
+
     def delete_sample(self, sample_id: Union[int, str]):
         """
         Parameters
@@ -1287,7 +1313,7 @@ class InventoryClient(ClientBase):
             params={"extraFields": toPut},
         )
 
-    def uploadAttachment(self, inventory_item: Union[str, dict], file) -> dict:
+    def upload_attachment(self, inventory_item: Union[str, dict], file) -> dict:
         """
         Uploads an attachment file to a sample, subsample or container.
         Parameters
@@ -1411,7 +1437,8 @@ class InventoryClient(ClientBase):
         id_to_copy = Id(item_to_duplicate)
         endpoint = id_to_copy.get_api_endpoint()
         rc = self.retrieve_api_results(
-            f"/{endpoint}/{id_to_copy.as_id()}/actions/duplicate", request_type="POST",
+            f"/{endpoint}/{id_to_copy.as_id()}/actions/duplicate",
+            request_type="POST",
         )
         if new_name is not None:
             rc = self.rename(rc, new_name)
@@ -1452,7 +1479,9 @@ class InventoryClient(ClientBase):
             raise ValueError("Supplied id is not a subsamples")
         data = {"content": note}
         return self.retrieve_api_results(
-            f"/subSamples/{ss_id.as_id()}/notes", request_type="POST", params=data,
+            f"/subSamples/{ss_id.as_id()}/notes",
+            request_type="POST",
+            params=data,
         )
 
     def get_workbenches(self) -> Sequence[dict]:
@@ -1506,6 +1535,59 @@ class InventoryClient(ClientBase):
         )
         return container
 
+    def add_locations_to_image_container(
+        self,
+        image_container: Union[int, str, Container, dict],
+        *locations: Sequence[tuple],
+    ) -> dict:
+        """
+        Adds 1 or more new locations to an existing image container.
+        If locations are empty, this  method has no effect.
+
+        Parameters
+        ----------
+        image_container : Union[int, str, Container, dict]
+            An identifier or representation of the iamge container to update.
+        *locations : Sequence[tuple]
+            A sequence of (x,y) coordinate tuples
+        Returns
+        -------
+        dict
+            The updated image container.
+        """
+        if len(locations) == 0:
+            return
+        image_c_id = self._id_as_container_id(image_container)
+        loci = [
+            {"newLocationRequest": True, "coordX": p[0], "coordY": p[1]}
+            for p in locations
+        ]
+        data = {"locations": loci}
+
+        updated = self.retrieve_api_results(
+            f"/containers/{image_c_id.as_id()}", request_type="PUT", params=data
+        )
+        return updated
+
+    def delete_locations_from_image_container(
+        self,
+        image_container: Union[int, str, Container, dict],
+        *locations: Sequence[int],
+    ):
+        if len(locations) == 0:
+            return
+        image_c_id = self._id_as_container_id(image_container)
+        to_delete = [
+            {"id": loc_id, "deleteLocationRequest": True} for loc_id in locations
+        ]
+        data = {"locations": to_delete}
+        updated = self.retrieve_api_results(
+            f"/containers/{image_c_id.as_id()}", request_type="PUT", params=data
+        )
+        return updated
+
+    ## TODO
+
     def create_list_container(
         self,
         name: str,
@@ -1624,7 +1706,11 @@ class InventoryClient(ClientBase):
             raise ValueError("Target must be a container")
         return id_target
 
-    def add_items_to_list_container(self, target_container_id, *item_ids: str,) -> list:
+    def add_items_to_list_container(
+        self,
+        target_container_id,
+        *item_ids: str,
+    ) -> list:
         """
         Adds 1 or more items to a list container
 
@@ -2014,7 +2100,8 @@ class InventoryClient(ClientBase):
         """
         id_to_restore = Id(sample_template_id)
         return self.retrieve_api_results(
-            f"/sampleTemplates/{id_to_restore.as_id()}/restore", request_type="PUT",
+            f"/sampleTemplates/{id_to_restore.as_id()}/restore",
+            request_type="PUT",
         )
 
     def transfer_sample_template_owner(
